CheckpointLocks

Struct CheckpointLocks 

pub struct CheckpointLocks { /* private fields */ }
A table of checkpoint locks indexed by key hash.

This provides a fixed-size array of locks that can be used to protect records during checkpoint operations. The lock for a particular key is determined by hashing the key and using the hash to index into the table.

Implementations

Source

impl CheckpointLocks

pub fn new() -> Self

Create a new empty checkpoint locks table

pub fn initialize(&mut self, size: u64)

Initialize the checkpoint locks table with the given size.

Arguments
  • size - Number of locks (must be power of 2 and less than i32::MAX)
Panics

Panics if size is not a power of 2 or exceeds i32::MAX.

pub fn with_size(size: u64) -> Self

Create and initialize a checkpoint locks table with the given size.

pub fn free(&mut self)

Free the lock table.

Panics

Debug builds will panic if any locks are still held.

pub fn size(&self) -> u64

Get the size of the lock table

pub fn is_empty(&self) -> bool

Check if the lock table is empty (size is 0)

pub fn get_lock(&self, hash: KeyHash) -> &AtomicCheckpointLock

Get the lock for a given key hash.

Panics

Panics if the lock table is empty (size is 0).

pub fn get_lock_by_hash(&self, hash: u64) -> &AtomicCheckpointLock

Get the lock for a given raw hash value.